Package: DCATS
Type: Package
Title: Differential Composition Analysis Transformed by a Similarity
        matrix
Version: 1.8.0
Authors@R: c(
    person("Xinyi", "Lin", , "linxy29@connect.hku.hk", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7780-2461")),
    person("Chuen", "Chau", email = "hadley@posit.co", role = "aut"),
    person("Yuanhua", "Huang", email = "jenny@posit.co", role = "aut"),
    person("Joshua W.K. Ho", role = "aut"))
Description: Methods to detect the differential composition abundances between 
    conditions in singel-cell RNA-seq experiments, with or without replicates. 
    It aims to correct bias introduced by missclaisification and enable 
    controlling of confounding covariates. To avoid the influence of proportion 
    change from big cell types, DCATS can use either total cell number or 
    specific reference group as normalization term.
Depends: R (>= 4.1.0), stats
License: MIT + file LICENSE
Imports: MCMCpack, matrixStats, robustbase, aod, e1071
Suggests: testthat (>= 3.0.0), knitr, Seurat, SeuratObject, tidyverse,
        rmarkdown, BiocStyle
VignetteBuilder: knitr
RoxygenNote: 7.2.3
biocViews: SingleCell, Normalization
Encoding: UTF-8
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/DCATS
git_branch: RELEASE_3_22
git_last_commit: ed0c9f6
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 03:28:45 UTC; biocbuild
Author: Xinyi Lin [aut, cre] (ORCID: <https://orcid.org/0000-0002-7780-2461>),
  Chuen Chau [aut],
  Yuanhua Huang [aut],
  Joshua W.K. Ho [aut]
Maintainer: Xinyi Lin <linxy29@connect.hku.hk>
